#
# spec file for package lash
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lash
Version:        0.5.4
Release:        4.4
Summary:        Linux Audio Session Handler
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://git.savannah.gnu.org/cgit/lash.git
Source:         %{name}-%{version}.tar.bz2
Source1:        %{name}.desktop
Source1000:     baselibs.conf
Patch0:         lash-gcc44.patch
Patch1:         lash-implicit-fortify-decl.patch
Patch2:         lash-info-entry.diff
Patch3:         lash-swig-2x.patch
Patch4:         lash-add-needed.patch
Patch5:         lash-resource.patch
Patch6:         lash-glibc-2.22.patch
Patch7:         0001-Fix-detection-of-Python-3.patch
Patch8:         lash-gcc14-fix.patch
BuildRequires:  alsa-devel
BuildRequires:  glibc-devel
BuildRequires:  gtk2-devel
BuildRequires:  libjack-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  libxml2-devel
BuildRequires:  python3-devel
BuildRequires:  readline-devel
BuildRequires:  swig

%description
LASH (formerly LADCCA) is a session management system for JACK and ALSA
audio applications on GNU/Linux. Its aim is to allow you to have many
different audio programs running at once and to save the setup, close
them down, then reload the setup at some other time.

%package -n liblash1
Summary:        Development package for LASH
Group:          Development/Libraries/C and C++

%description -n liblash1
This package contains the library for the LASH system.

%package -n python3-lash
Summary:        Python bindings for LASH
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description -n python3-lash
This package contains the language bindings for Python.

%package -n lash-devel
Summary:        Development package for LASH
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       liblash1 = %{version}
Requires:       libuuid-devel
Requires:       readline-devel

%description -n lash-devel
This package contains the development files for the LASH system.

%prep
%setup -q

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3
%patch -P 4
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1

%build
./autogen.sh
%configure \
  --enable-static=no \
  --datadir=%{_datadir}/%{name}-%{version}
%make_build

%install
%make_install
rm -f %{buildroot}%{python3_sitelib}/_lash.la
rm -f %{buildroot}%{python3_sitelib}/_lash.a
chmod 644 %{buildroot}/%{python3_sitelib}/lash.py
find %{buildroot} -type f -name "*.la" -delete -print

# links for so.2 have to be made for older packages that link against liblash
pushd %{buildroot}%{_libdir}
        ln -s liblash.so.1 liblash.so.2
        ln -s liblash.so.1 liblash.so.2.0.0
popd

%files
%doc AUTHORS ChangeLog NEWS README TODO
%license COPYING
%{_bindir}/*
%{_datadir}/%{name}-%{version}/

%files -n liblash1
%{_libdir}/liblash.so.*

%files -n lash-devel
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files -n python3-lash
%doc pylash/test.py
%{python3_sitelib}/_lash.so
%{python3_sitelib}/lash.py

%post -n liblash1 -p /sbin/ldconfig
%postun -n liblash1 -p /sbin/ldconfig

%changelog
* Tue Aug 27 2024 Takashi Iwai <tiwai@suse.com>
- Fix the build error with gcc14:
  lash-gcc14-fix.patch
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Apr 17 2021 Simon Lees <sflees@suse.de>
- Greatly simplify 0001-Fix-detection-of-Python-3.patch to use
  pkg-config so that it also works with Leap 15.3
- Fix up parts of the specfile so python3 is used in Leap 15.3
* Wed Oct 21 2020 Simon Lees <sflees@suse.de>
- Run spec cleaner
- Use python3 everywhere
* Thu Jul 23 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Build with python3 on TW, add 0001-Fix-detection-of-Python-3.patch
- Clean up spec file
* Tue Aug 11 2015 idonmez@suse.com
- Add baselibs.conf as source
* Tue Aug 11 2015 dimstar@opensuse.org
- Add lash-glibc-2.22.patch: Fix build with glibc 2.22. getattrinfo
  is now only declared in _POSIX_C_SOURCE >= 200112L.
* Sun Jul 29 2012 aj@suse.de
- Add missing sys/resource.h include (glibc 2.16)
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Mon Sep 19 2011 crrodriguez@opensuse.org
- Link with libm as well.
* Thu May 26 2011 idonmez@novell.com
- Add lash-swig-2x.patch: support swig 2.x
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed test for obsolete openSUSE versions
* Sun Sep 12 2010 stephan.barth@novell.com
- update to version 0.5.4 which contains a lot of changes
- reworked the spec file to remove all warnings
- added version specific datadir tags
- added python package
- needed to create links for liblash.so.2 for downward compatibility
- removed obsolete lash-nogtk1.diff which was there for GTK1
- removed now obsolete lash-automake-fix.diff
* Mon Jun 29 2009 tiwai@suse.de
- fix buildrequires to use libjack-devel
- fix URL
* Mon Mar 23 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies and pkgconfig files
* Fri Sep 14 2007 aj@suse.de
- Cleanup rpmlint warnings.
- Remove whitespace to build package again.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 17 2005 tiwai@suse.de
- renamed to lash
- updated to version 0.5.0.
* Wed Sep 22 2004 mskibbe@suse.de
- change specfile(suse_update_desktopfile)
* Tue Apr 27 2004 ro@suse.de
- added -fno-strict-aliasing
* Mon Feb 16 2004 tiwai@suse.de
- build as non-root.
* Thu Nov 20 2003 tiwai@suse.de
- updated to 0.4.0.
- added libxml2 and devel to neededforbuild.
* Tue Sep 16 2003 tiwai@suse.de
- added desktop icon.
* Fri Aug 29 2003 tiwai@suse.de
- added the texinto entry (bug #29588).
* Thu Aug 28 2003 tiwai@suse.de
- fixed the missing inclusion of limits.h.
* Sat Aug 16 2003 adrian@suse.de
- add desktop file
* Thu Jul  3 2003 tiwai@suse.de
- initial version: 0.3.1.
